Coverage report

Module | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
/home/runner/.local/share/hatch/env/virtual/importnb/KA2AwMZG/test.stdlib/lib/python3.9/site-packages/importnb/__init__.py | 20 | 8 | 0 | 60%
/home/runner/.local/share/hatch/env/virtual/importnb/KA2AwMZG/test.stdlib/lib/python3.9/site-packages/importnb/__main__.py | 6 | 0 | 0 | 100%
/home/runner/.local/share/hatch/env/virtual/importnb/KA2AwMZG/test.stdlib/lib/python3.9/site-packages/importnb/_json_parser.py | 1897 | 896 | 0 | 53%
/home/runner/.local/share/hatch/env/virtual/importnb/KA2AwMZG/test.stdlib/lib/python3.9/site-packages/importnb/_version.py | 2 | 0 | 0 | 100%
/home/runner/.local/share/hatch/env/virtual/importnb/KA2AwMZG/test.stdlib/lib/python3.9/site-packages/importnb/decoder.py | 69 | 5 | 0 | 93%
/home/runner/.local/share/hatch/env/virtual/importnb/KA2AwMZG/test.stdlib/lib/python3.9/site-packages/importnb/docstrings.py | 37 | 2 | 0 | 95%
/home/runner/.local/share/hatch/env/virtual/importnb/KA2AwMZG/test.stdlib/lib/python3.9/site-packages/importnb/finder.py | 57 | 1 | 0 | 98%
/home/runner/.local/share/hatch/env/virtual/importnb/KA2AwMZG/test.stdlib/lib/python3.9/site-packages/importnb/loader.py | 229 | 13 | 0 | 94%
/home/runner/.local/share/hatch/env/virtual/importnb/KA2AwMZG/test.stdlib/lib/python3.9/site-packages/importnb/utils/__init__.py | 0 | 0 | 0 | 100%
/home/runner/.local/share/hatch/env/virtual/importnb/KA2AwMZG/test.stdlib/lib/python3.9/site-packages/importnb/utils/ipython.py | 45 | 45 | 0 | 0%
/home/runner/.local/share/hatch/env/virtual/importnb/KA2AwMZG/test.stdlib/lib/python3.9/site-packages/importnb/utils/pytest_importnb.py | 24 | 13 | 0 | 46%
Total | 2386 | 983 | 0 | 59%

No items found using the specified filter.